@@ -30,7 +30,7 @@ use IO::Socket ();
 
 package RPC::PlClient;
 
-$RPC::PlClient::VERSION = '0.2010';
+$RPC::PlClient::VERSION = '0.2011';
 @RPC::PlClient::ISA = qw(Net::Daemon::Log);
 
 
@@ -80,8 +80,8 @@ sub new ($@) {
     $self->RPC::PlServer::Comm::Write([$app, $version, $user, $password]);
     $self->Debug("Waiting for server's response ...");
     my $reply = $self->RPC::PlServer::Comm::Read();
-    die "Expected server to return an array ref"
-	unless $reply && ref($reply) eq 'ARRAY';
+    die "Unexpected EOF from server" unless defined($reply);
+    die "Expected server to return an array ref" unless ref($reply) eq 'ARRAY';
     my $msg = defined($reply->[1]) ? $reply->[1] : '';
     die "Refused by server: $msg" unless $reply->[0];
     $self->Debug("Logged in, server replies: $msg");
@@ -110,13 +110,9 @@ sub Call ($@) {
     my $self = shift;
     $self->RPC::PlServer::Comm::Write([@_]);
     my $msg = $self->RPC::PlServer::Comm::Read();
-    if (!$msg  ||  !ref($msg)) {
-	die "Expected server to return a reference";
-    } elsif (ref($msg) eq 'SCALAR') {
-	die "Server returned error: $$msg";
-    } elsif (ref($msg) ne 'ARRAY') {
-	die "Expected server to return an array ref";
-    }
+    die "Unexpected EOF while waiting for server reply" unless defined($msg);
+    die "Server returned error: $$msg" if ref($msg) eq 'SCALAR';
+    die "Expected server to return an array ref" unless ref($msg) eq 'ARRAY';
     @$msg;
 }
 
