@@ -29,7 +29,7 @@ use RPC::PlServer::Comm ();
 package RPC::PlServer;
 
 @RPC::PlServer::ISA = qw(Net::Daemon RPC::PlServer::Comm);
-$RPC::PlServer::VERSION = '0.2010';
+$RPC::PlServer::VERSION = '0.2011';
 
 
 ############################################################################
@@ -146,9 +146,8 @@ sub Accept ($) {
     }
 
     my $msg = $self->RPC::PlServer::Comm::Read();
-    if (ref($msg) ne 'ARRAY') {
-	die "Login message: Expected array, got $msg";
-    }
+    die "Unexpected EOF from client" unless defined $msg;
+    die "Login message: Expected array, got $msg" unless ref($msg) eq 'ARRAY';
 
     my $app      = $self->{'application'} = $msg->[0] || '';
     my $version  = $self->{'version'}     = $msg->[1] || 0;
@@ -234,12 +233,12 @@ sub Run ($) {
     my $self = shift;
     my $socket = $self->{'socket'};
 
-    while (!$self->Done()  &&  !$socket->eof()) {
+    while (!$self->Done()) {
 	my $msg = $self->RPC::PlServer::Comm::Read();
+	last unless defined($msg);
+	die "Expected array" unless ref($msg) eq 'ARRAY';
 	my($error, $command);
-	if (ref($msg) ne 'ARRAY') {
-	    $error = "Expected array";
-	} elsif (!($command = shift @$msg)) {
+	if (!($command = shift @$msg)) {
 	    $error = "Expected method name";
 	} else {
 	    if ($self->{'methods'}) {
